
From: Adrian Bunk <bunk@stusta.de>

- arch/i386/mm/boot_ioremap.c: make a variable static
- frv/ppc highmem.c: remove stale kmap_init prototypes
- arch/um/kernel/mem.c: make kmap_init static
- arch/i386/mm/init.c: make five functions static

Signed-off-by: Adrian Bunk <bunk@stusta.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/i386/mm/boot_ioremap.c |    4 ++--
 25-akpm/arch/i386/mm/init.c         |    8 ++++----
 25-akpm/arch/um/kernel/mem.c        |    2 +-
 25-akpm/include/asm-frv/highmem.h   |    2 --
 25-akpm/include/asm-i386/highmem.h  |    2 --
 25-akpm/include/asm-ppc/highmem.h   |    2 --
 6 files changed, 7 insertions(+), 13 deletions(-)

diff -puN arch/i386/mm/boot_ioremap.c~mostly-i386-mm-cleanup arch/i386/mm/boot_ioremap.c
--- 25/arch/i386/mm/boot_ioremap.c~mostly-i386-mm-cleanup	2005-02-28 17:37:31.000000000 -0800
+++ 25-akpm/arch/i386/mm/boot_ioremap.c	2005-02-28 17:37:31.000000000 -0800
@@ -61,8 +61,8 @@ static void __boot_ioremap(unsigned long
 /* the virtual space we're going to remap comes from this array */
 #define BOOT_IOREMAP_PAGES 4
 #define BOOT_IOREMAP_SIZE (BOOT_IOREMAP_PAGES*PAGE_SIZE)
-__initdata char boot_ioremap_space[BOOT_IOREMAP_SIZE] 
-		__attribute__ ((aligned (PAGE_SIZE)));
+static __initdata char boot_ioremap_space[BOOT_IOREMAP_SIZE]
+		       __attribute__ ((aligned (PAGE_SIZE)));
 
 /*
  * This only applies to things which need to ioremap before paging_init()
diff -puN arch/i386/mm/init.c~mostly-i386-mm-cleanup arch/i386/mm/init.c
--- 25/arch/i386/mm/init.c~mostly-i386-mm-cleanup	2005-02-28 17:37:31.000000000 -0800
+++ 25-akpm/arch/i386/mm/init.c	2005-02-28 17:37:31.000000000 -0800
@@ -239,7 +239,7 @@ EXPORT_SYMBOL(kmap_pte);
 #define kmap_get_fixmap_pte(vaddr)					\
 	pte_offset_kernel(pmd_offset(pud_offset(pgd_offset_k(vaddr), vaddr), (vaddr)), (vaddr))
 
-void __init kmap_init(void)
+static void __init kmap_init(void)
 {
 	unsigned long kmap_vstart;
 
@@ -250,7 +250,7 @@ void __init kmap_init(void)
 	kmap_prot = PAGE_KERNEL;
 }
 
-void __init permanent_kmaps_init(pgd_t *pgd_base)
+static void __init permanent_kmaps_init(pgd_t *pgd_base)
 {
 	pgd_t *pgd;
 	pud_t *pud;
@@ -281,7 +281,7 @@ void __init one_highpage_init(struct pag
 }
 
 #ifndef CONFIG_DISCONTIGMEM
-void __init set_highmem_pages_init(int bad_ppro) 
+static void __init set_highmem_pages_init(int bad_ppro)
 {
 	int pfn;
 	for (pfn = highstart_pfn; pfn < highend_pfn; pfn++)
@@ -503,7 +503,7 @@ void __init paging_init(void)
  * but fortunately the switch to using exceptions got rid of all that.
  */
 
-void __init test_wp_bit(void)
+static void __init test_wp_bit(void)
 {
 	printk("Checking if this processor honours the WP bit even in supervisor mode... ");
 
diff -puN arch/um/kernel/mem.c~mostly-i386-mm-cleanup arch/um/kernel/mem.c
--- 25/arch/um/kernel/mem.c~mostly-i386-mm-cleanup	2005-02-28 17:37:31.000000000 -0800
+++ 25-akpm/arch/um/kernel/mem.c	2005-02-28 17:37:31.000000000 -0800
@@ -138,7 +138,7 @@ pgprot_t kmap_prot;
 	pte_offset_kernel(pmd_offset(pud_offset(pgd_offset_k(vaddr), (vaddr)),\
  			  (vaddr)), (vaddr))
 
-void __init kmap_init(void)
+static void __init kmap_init(void)
 {
 	unsigned long kmap_vstart;
 
diff -puN include/asm-frv/highmem.h~mostly-i386-mm-cleanup include/asm-frv/highmem.h
--- 25/include/asm-frv/highmem.h~mostly-i386-mm-cleanup	2005-02-28 17:37:31.000000000 -0800
+++ 25-akpm/include/asm-frv/highmem.h	2005-02-28 17:37:31.000000000 -0800
@@ -44,8 +44,6 @@ extern unsigned long highstart_pfn, high
 #define kmap_pte ______kmap_pte_in_TLB
 extern pte_t *pkmap_page_table;
 
-extern void kmap_init(void);
-
 #define flush_cache_kmaps()  do { } while (0)
 
 /*
diff -puN include/asm-i386/highmem.h~mostly-i386-mm-cleanup include/asm-i386/highmem.h
--- 25/include/asm-i386/highmem.h~mostly-i386-mm-cleanup	2005-02-28 17:37:31.000000000 -0800
+++ 25-akpm/include/asm-i386/highmem.h	2005-02-28 17:37:31.000000000 -0800
@@ -33,8 +33,6 @@ extern pte_t *kmap_pte;
 extern pgprot_t kmap_prot;
 extern pte_t *pkmap_page_table;
 
-extern void kmap_init(void);
-
 /*
  * Right now we initialize only a single pte table. It can be extended
  * easily, subsequent pte tables have to be allocated in one physical
diff -puN include/asm-ppc/highmem.h~mostly-i386-mm-cleanup include/asm-ppc/highmem.h
--- 25/include/asm-ppc/highmem.h~mostly-i386-mm-cleanup	2005-02-28 17:37:31.000000000 -0800
+++ 25-akpm/include/asm-ppc/highmem.h	2005-02-28 17:37:31.000000000 -0800
@@ -35,8 +35,6 @@ extern pte_t *kmap_pte;
 extern pgprot_t kmap_prot;
 extern pte_t *pkmap_page_table;
 
-extern void kmap_init(void) __init;
-
 /*
  * Right now we initialize only a single pte table. It can be extended
  * easily, subsequent pte tables have to be allocated in one physical
_
